@@ -6,7 +6,7 @@ BEGIN {
   $MetaPOD::Assembler::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $MetaPOD::Assembler::VERSION = '0.1.3';
+  $MetaPOD::Assembler::VERSION = '0.2.0';
 }
 
 # ABSTRACT: Glue layer that dispatches segments to a constructed Result
@@ -119,7 +119,7 @@ MetaPOD::Assembler - Glue layer that dispatches segments to a constructed Result
 
 =head1 VERSION
 
-version 0.1.3
+version 0.2.0
 
 =head1 SYNOPSIS
 
@@ -177,11 +177,12 @@ by parsing the given C<$segment_hash>
 
 =head2 format_map
 
-=begin MetaPOD::JSON v1.0.0
+=begin MetaPOD::JSON v1.1.0
 
 {
     "namespace":"MetaPOD::Assembler",
-    "inherits":"Moo::Object"
+    "inherits":"Moo::Object",
+    "interface":"class"
 }
 
 
