@@ -6,7 +6,7 @@ BEGIN {
   $MetaPOD::Format::JSON::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $MetaPOD::Format::JSON::VERSION = '0.1.3';
+  $MetaPOD::Format::JSON::VERSION = '0.2.0';
 }
 
 # ABSTRACT: Reference implementation of a C<JSON> based MetaPOD Format
@@ -22,12 +22,17 @@ my $dispatch_table = [
   {
     version => version->parse('v1.0.0'),
     method  => 'v1',
+  },
+  {
+    version => version->parse('v1.1.0'),
+    method  => 'v1_1',
   }
+
 ];
 
 
 sub supported_versions {
-  return qw( v1.0.0 );
+  return qw( v1.0.0 v1.1.0 );
 }
 
 sub _do_for_key {
@@ -65,10 +70,39 @@ sub _add_does_v1 {
   croak 'Unsupported reftype ' . ref $does;
 }
 
-sub _add_segment_v1 {
-  my ( $self, $data, $result ) = @_;
-  require JSON;
-  my $data_decoded = JSON->new->decode($data);
+sub _check_interface_v1_1 {
+  my ( $self, @ifs ) = @_;
+  my $supported = {
+    'class'        => 1,
+    'role'         => 1,
+    'type_library' => 1,
+    'exporter'     => 1,
+    'single_class' => 1,
+    'functions'    => 1,
+  };
+  for my $if (@ifs) {
+    if ( not exists $supported->{$if} ) {
+      croak("interface type $if unsupported in v1.1.0");
+    }
+  }
+  return $self;
+}
+
+sub _add_interface_v1_1 {
+  my ( $self, $ifs, $result ) = @_;
+  if ( defined $ifs and not ref $ifs ) {
+    $self->_check_interface_v1_1($ifs);
+    return $result->add_interface($ifs);
+  }
+  if ( defined $ifs and ref $ifs eq 'ARRAY' ) {
+    $self->_check_interface_v1_1( @{$ifs} );
+    return $result->add_interface( @{$ifs} );
+  }
+  croak 'Unsupported reftype ' . ref $ifs;
+}
+
+sub _real_add_segment_v1 {
+  my ( $self, $data_decoded, $result ) = @_;
   _do_for_key(
     $data_decoded => 'namespace' => sub {
       $self->_add_namespace_v1( $_, $result );
@@ -84,7 +118,36 @@ sub _add_segment_v1 {
       $self->_add_does_v1( $_, $result );
     }
   );
+  return $result;
+}
 
+sub _real_add_segment_v1_1 {
+  my ( $self, $data_decoded, $result ) = @_;
+  $self->_real_add_segment_v1( $data_decoded, $result );
+  _do_for_key(
+    $data_decoded => 'interface' => sub {
+      $self->_add_interface_v1_1( $_, $result );
+    }
+  );
+  return $result;
+}
+
+sub _add_segment_v1 {
+  my ( $self, $data, $result ) = @_;
+  require JSON;
+  my $data_decoded = JSON->new->decode($data);
+  $self->_real_add_segment_v1( $data_decoded, $result );
+  if ( keys %{$data_decoded} ) {
+    croak 'Keys found not supported in this version: <' . ( join q{,}, keys %{$data_decoded} ) . '>';
+  }
+  return $result;
+}
+
+sub _add_segment_v1_1 {
+  my ( $self, $data, $result ) = @_;
+  require JSON;
+  my $data_decoded = JSON->new->decode($data);
+  $self->_real_add_segment_v1_1( $data_decoded, $result );
   if ( keys %{$data_decoded} ) {
     croak 'Keys found not supported in this version: <' . ( join q{,}, keys %{$data_decoded} ) . '>';
   }
@@ -117,7 +180,7 @@ MetaPOD::Format::JSON - Reference implementation of a C<JSON> based MetaPOD Form
 
 =head1 VERSION
 
-version 0.1.3
+version 0.2.0
 
 =head1 SYNOPSIS
 
@@ -129,18 +192,19 @@ This is the reference implementation of L<< C<MetaPOD::JSON>|MetaPOD::JSON >>
 
 The versions this module supports
 
-    returns qw( v1.0.0 )
+    returns qw( v1.0.0 v1.1.0 )
 
 =head2 add_segment
 
 See L<< C<::Role::Format>|MetaPOD::Role::Format >> for the specification of the C<add_segment> method.
 
-=begin MetaPOD::JSON v1.0.0
+=begin MetaPOD::JSON v1.1.0
 
 {
     "namespace":"MetaPOD::Format::JSON",
     "inherits":"Moo::Object",
-    "does":"MetaPOD::Role::Format"
+    "does":"MetaPOD::Role::Format",
+    "interface": "single_class"
 }
 
 
